@@ -74,9 +74,3 @@ class NoAPIKeyError(ISBNToolsDevException):
     """ Exception raised when the API Key for a service is not found
     """
     message = "this service needs an API key"
-
-
-class NotImplementedError(ISBNToolsDevException):
-    """ Exception raised when the methods wasn't implemented yet!
-    """
-    message = "this method wasn't implemented yet"
