@@ -6,6 +6,8 @@ import logging
 from .data.data4mask import ranges
 from .core import canonical, to_isbn13
 
+logger = logging.getLogger(__name__)
+
 
 def mask(isbn, separator='-'):
     """ Transforms a canonical ISBN to a `masked` one
@@ -50,5 +52,5 @@ def mask(isbn, separator='-'):
             check = check10
         return separator.join([group, ib[cur + 1:cur + idx + 1],
                               ib[cur + idx + 1:-1], check])
-    logging.warning('identifier not found! Please, update the program.')
+    logger.warning('identifier not found! Please, update the program.')
     return
